The Wily project is dedicated to providing a respectful, harassment-free community for everyone. We do not tolerate harassment or bullying of any community member in any form. This does not only extend to members to local Wily communities, but to anyone who chooses to become involved in the larger Wily community of users, developers and integrators through events or interactions.

Harassment includes offensive verbal/electronic comments related to personal characteristics or choices, sexual images or comments in public or online spaces, deliberate intimidation, bullying, stalking, following, harassing photography or recording, sustained disruption of talks, electronic meetings, physical meetings or other events, inappropriate physical contact, or unwelcome sexual attention. Participants asked to stop any harassing or bullying behavior are expected to comply immediately.

If a participant engages in harassing behavior, representatives of the community may take reasonable action they deem appropriate, including warning the offender, expulsion from any Wily event, or expulsion from mailing lists, discussion boards and other electronic communications channels to resolve the issue.

If you are being harassed, notice that someone else is being harassed, or have any other concerns, please act to intercede or ask for help from any member of the Wily community or organizers/representatives of any physical events put on under the auspices of Wily.

This Code of Conduct has been adapted from the [Plone Foundation](http://plone.org/foundation/materials/foundation-resolutions/code-of-conduct) and is licensed under a [Creative Commons Attribution-Share Alike 3.0 Unported license](http://creativecommons.org/licenses/by-sa/3.0/)
